Changes in directory llvm/include/llvm:

Value.h updated: 1.80 -> 1.81
---
Log message:

Make ValueSymbolTable (temporarily) a friend of Value so it can mod the 
Name of Value instances.


---
Diffs of the changes:  (+2 -1)

 Value.h |    3 ++-
 1 files changed, 2 insertions(+), 1 deletion(-)


Index: llvm/include/llvm/Value.h
diff -u llvm/include/llvm/Value.h:1.80 llvm/include/llvm/Value.h:1.81
--- llvm/include/llvm/Value.h:1.80      Fri Dec 16 18:18:06 2005
+++ llvm/include/llvm/Value.h   Tue Jan 10 03:45:57 2006
@@ -51,7 +51,8 @@
   PATypeHolder Ty;
   Use *UseList;
 
-  friend class SymbolTable;    // Allow SymbolTable to directly poke Name.
+  friend class ValueSymbolTable; // Allow ValueSymbolTable to directly mod 
Name.
+  friend class SymbolTable;      // Allow SymbolTable to directly poke Name.
   std::string Name;
 
   void operator=(const Value &);     // Do not implement



_______________________________________________
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits

Reply via email to